/*-------------------------------------------------------------------------+
| Copyright 2012 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editor.annotations;

import static org.eclipse.jface.text.source.ImageUtilities.drawImage;

import org.eclipse.jface.text.source.Annotation;
import org.eclipse.jface.text.source.IAnnotationAccess;
import org.eclipse.jface.text.source.IAnnotationAccessExtension;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.widgets.Canvas;

/**
 * Class providing annotation marker access.
 * 
 * @author doebber
 */
public class AnnotationMarkerAccess implements IAnnotationAccess, IAnnotationAccessExtension {
	/** {@inheritDoc} */
	@Override
	public Object getType(Annotation annotation) {
		return annotation.getType();
	}

	/** {@inheritDoc} */
	@Override
	public boolean isMultiLine(Annotation annotation) {
		return true;
	}

	/** {@inheritDoc} */
	@Override
	public boolean isTemporary(Annotation annotation) {
		return !annotation.isPersistent();
	}

	/** {@inheritDoc} */
	@Override
	public String getTypeLabel(Annotation annotation) {
		if(annotation instanceof ErrorAnnotation) {
			return "Errors";
		}

		return null;
	}

	/** {@inheritDoc} */
	@Override
	public int getLayer(Annotation annotation) {
		if(annotation instanceof ErrorAnnotation) {
			return ((ErrorAnnotation)annotation).getLayer();
		}

		return 0;
	}

	/** {@inheritDoc} */
	@Override
	public void paint(Annotation annotation, GC gc, Canvas canvas, Rectangle bounds) {
		drawImage(((ErrorAnnotation)annotation).getImage(), gc, canvas, bounds, SWT.CENTER,
				SWT.TOP);
	}

	/** {@inheritDoc} */
	@Override
	public boolean isPaintable(Annotation annotation) {
		if(annotation instanceof ErrorAnnotation) {
			return ((ErrorAnnotation)annotation).getImage() != null;
		}

		return false;
	}

	/** {@inheritDoc} */
	@Override
	public boolean isSubtype(Object annotationType, Object potentialSupertype) {
		if(annotationType.equals(potentialSupertype)) {
			return true;
		}

		return false;
	}

	/** {@inheritDoc} */
	@Override
	public Object[] getSupertypes(Object annotationType) {
		return new Object[0];
	}
}
