/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.jface;

import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.swt.graphics.Image;

import org.conqat.lib.commons.assertion.CCSMAssert;
import org.conqat.lib.commons.string.StringUtils;

/**
 * Base class for column label provider that expect a certain type.
 * 
 * @author schwitze
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 83DBAEDC7702B1BDF01CC2D8CEB89A22
 */
public abstract class TypedColumnLabelProviderBase<T> extends
		ColumnLabelProvider {

	/** Expected type. */
	private final Class<T> type;

	/** Create label provider for expected type. */
	public TypedColumnLabelProviderBase(Class<T> type) {
		this.type = type;
	}

	/**
	 * Checks if element is of expected type and forwards to
	 * {@link #obtainText(Object)}.
	 * 
	 * @throws AssertionError
	 *             if element is not of expected type.
	 */
	@SuppressWarnings("unchecked")
	@Override
	public final String getText(Object element) {
		CCSMAssert.isTrue(type.isInstance(element), "Expected element to be a "
				+ type);
		return obtainText((T) element);
	}

	/**
	 * Checks if element is of expected type and forwards to
	 * {@link #obtainImage(Object)}.
	 * 
	 * @throws AssertionError
	 *             if element is not of expected type.
	 */
	@SuppressWarnings("unchecked")
	@Override
	public final Image getImage(Object element) {
		CCSMAssert.isTrue(type.isInstance(element), "Expected element to be a "
				+ type);
		return obtainImage((T) element);
	}

	/**
	 * This should be overridden to define text for element. This implementation
	 * returns the empty string.
	 */
	protected String obtainText(@SuppressWarnings("unused")
	T element) {
		return StringUtils.EMPTY_STRING;
	}

	/**
	 * This should be overridden to define text for element. This implementation
	 * returns <code>null</code>.
	 */
	protected Image obtainImage(@SuppressWarnings("unused")
	T element) {
		return null;
	}
}